@@ -1,6 +1,6 @@
 /*
     DeaDBeeF -- the music player
-    Copyright (C) 2009-2016 Alexey Yakovenko and other contributors
+    Copyright (C) 2009-2016 Oleksiy Yakovenko and other contributors
 
     This software is provided 'as-is', without any express or implied
     warranty.  In no event will the authors be held liable for any damages
@@ -26,9 +26,15 @@
 
 @interface CoverManager : NSObject
 
-+ (CoverManager *)defaultCoverManager;
-- (CoverManager *)init;
-@property (nonatomic,readonly) NSImage *defaultCover;
-- (NSImage *)getCoverForTrack:(DB_playItem_t *)track withCallbackWhenReady:(void (*) (NSImage *img, void *user_data))callback withUserDataForCallback:(void *)user_data;
+@property (class,nonatomic,readonly,nonnull) CoverManager *shared;
+
++ (void)freeSharedInstance;
+
+@property (atomic) BOOL isTerminating;
+
+- (nullable NSImage *)coverForTrack:(nonnull DB_playItem_t *)track sourceId:(int64_t)sourceId completionBlock:(nonnull void (^) (NSImage * _Nullable img))completionBlock;
+- (nullable NSImage *)coverForTrack:(nonnull DB_playItem_t *)track completionBlock:(nonnull void (^) (NSImage * _Nullable img))completionBlock;
+- (nullable NSImage *)createScaledImage:(NSImage * _Nonnull)image newSize:(CGSize)size;
+- (CGSize)desiredSizeForImageSize:(CGSize)imageSize availableSize:(CGSize)availableSize;
 
 @end
