@@ -1,6 +1,6 @@
 /*
     DeaDBeeF CoreAudio output plugin
-    Copyright (C) 2009-2017 Alexey Yakovenko and other contributors
+    Copyright (C) 2009-2017 Oleksiy Yakovenko and other contributors
 
     This software is provided 'as-is', without any express or implied
     warranty.  In no event will the authors be held liable for any damages
@@ -24,20 +24,16 @@
 #include "../../deadbeef.h"
 #include <AudioUnit/AudioUnit.h>
 #include <AudioToolbox/AudioToolbox.h>
-#import <IOKit/pwr_mgt/IOPMLib.h>
+#include <IOKit/pwr_mgt/IOPMLib.h>
 
 static DB_functions_t *deadbeef;
 static DB_output_t plugin;
 
-#define trace(...) { deadbeef->log_detailed (&plugin.plugin, 0, __VA_ARGS__); }
+#define trace(...) { deadbeef->log_detailed (&plugin.plugin, DDB_LOG_LAYER_INFO, __VA_ARGS__); }
 
 static ddb_playback_state_t state = DDB_PLAYBACK_STATE_STOPPED;
 static uint64_t mutex;
 
-// audiounit impl
-#include <AudioUnit/AudioUnit.h>
-#include <AudioToolbox/AudioToolbox.h>
-
 static AudioDeviceID device_id;
 static AudioDeviceIOProcID process_id;
 static AudioStreamBasicDescription default_format;
@@ -52,14 +48,16 @@ ca_fmtchanged (AudioObjectID inObjectID, UInt32 inNumberAddresses, const AudioOb
 static OSStatus
 ca_buffer_callback(AudioDeviceID inDevice, const AudioTimeStamp * inNow, const AudioBufferList * inInputData, const AudioTimeStamp * inInputTime, AudioBufferList * outOutputData, const AudioTimeStamp * inOutputTime, void * inClientData);
 
-static int
-ca_free (void);
-static int
-ca_init (void);
-static int
-ca_play (void);
-static int
-ca_pause (void);
+static ddb_playback_state_t
+ca_state (void);
+
+static void
+ca_set_state(ddb_playback_state_t st);
+
+static int ca_free (void);
+static int ca_init (void);
+static int ca_play (void);
+static int ca_pause (void);
 
 static UInt32
 GetNumberAvailableNominalSampleRateRanges()
@@ -139,26 +137,6 @@ ca_apply_format (void) {
     if (req_format.mSampleRate > 0) {
         req_format.mSampleRate = get_best_samplerate ((int)req_format.mSampleRate, avail_samplerates, num_avail_samplerates);
 
-        // setting nominal samplerate doesn't work in most cases, and requires some timing trickery
-#if 0
-        AudioObjectPropertyAddress nsr = {
-            kAudioDevicePropertyNominalSampleRate,
-            kAudioObjectPropertyScopeGlobal,
-            kAudioObjectPropertyElementMaster
-        };
-        sz = sizeof(Float64);
-        Float64 sr = req_format.mSampleRate;
-        err = AudioObjectSetPropertyData(device_id, &nsr, 0, NULL, sz, &sr);
-        if (err != noErr) {
-            trace ("AudioObjectSetPropertyData kAudioDevicePropertyNominalSampleRate: %x\n", err);
-        }
-
-        err = AudioObjectGetPropertyData(device_id, &nsr, 0, NULL, &sz, &sr);
-        if (err != noErr) {
-            trace ("AudioObjectGetPropertyData kAudioDevicePropertyNominalSampleRate: %x\n", err);
-        }
-#endif
-
         AudioObjectPropertyAddress theAddress = {
             kAudioDevicePropertyStreamFormat,
             kAudioDevicePropertyScopeOutput,
@@ -166,17 +144,14 @@ ca_apply_format (void) {
         };
         sz = sizeof (AudioStreamBasicDescription);
 
-#if 0
-        static AudioStreamBasicDescription current_format;
-        err = AudioObjectGetPropertyData(device_id, &theAddress, 0, NULL, &sz, &current_format);
-        if (err != noErr) {
-            trace ("AudioObjectGetPropertyData kAudioDevicePropertyStreamFormat: %x\n", err);
-            goto error;
-        }
-#endif
-
         // NOTE: for unsupported formats, this call may cause bogus messages to appear in console / debug output.
         err = AudioObjectSetPropertyData(device_id, &theAddress, 0, NULL, sz, &req_format);
+        if (err != noErr && req_format.mChannelsPerFrame == 1) {
+            req_format.mChannelsPerFrame = 2;
+            req_format.mBytesPerFrame *= 2;
+            req_format.mBytesPerPacket *= 2;
+            err = AudioObjectSetPropertyData(device_id, &theAddress, 0, NULL, sz, &req_format);
+        }
         if (err != noErr) {
             err = AudioObjectSetPropertyData(device_id, &theAddress, 0, NULL, sz, &default_format);
             // ignore the result of this operation -- it may fail even when attempting to change to the same format that's current right now
@@ -309,7 +284,7 @@ ca_init (void) {
         return -1;
     }
 
-    UInt32 bufsize = 4096;
+    UInt32 bufsize = 1024;
     sz = sizeof (bufsize);
     theAddress.mSelector = kAudioDevicePropertyBufferFrameSize;
     err = AudioObjectSetPropertyData(device_id, &theAddress, 0, NULL, sz, &bufsize);
@@ -469,18 +444,17 @@ ca_play (void) {
         }
     }
 
-    deadbeef->mutex_lock (mutex);
-    if (state != DDB_PLAYBACK_STATE_PLAYING) {
+    ddb_playback_state_t current_state = ca_state();
+
+    if (current_state != DDB_PLAYBACK_STATE_PLAYING) {
         err = AudioDeviceStart (device_id, ca_buffer_callback);
         if (err != noErr) {
             trace ("AudioDeviceStart: %x\n", err);
-            state = DDB_PLAYBACK_STATE_STOPPED;
-            deadbeef->mutex_unlock (mutex);
+            ca_set_state(DDB_PLAYBACK_STATE_STOPPED);
             return -1;
         }
-        state = DDB_PLAYBACK_STATE_PLAYING;
+        ca_set_state(DDB_PLAYBACK_STATE_PLAYING);
     }
-    deadbeef->mutex_unlock (mutex);
 
     ca_prevent_sleep ();
 
@@ -496,17 +470,16 @@ ca_stop (void) {
         return 0;
     }
 
-    deadbeef->mutex_lock (mutex);
-    if (state != DDB_PLAYBACK_STATE_STOPPED) {
+    ddb_playback_state_t curr_state = ca_state();
+
+    if (curr_state != DDB_PLAYBACK_STATE_STOPPED) {
         err = AudioDeviceStop (device_id, ca_buffer_callback);
-        state = DDB_PLAYBACK_STATE_STOPPED;
+        ca_set_state(DDB_PLAYBACK_STATE_STOPPED);
         if (err != noErr) {
             trace ("AudioDeviceStop: %x\n", err);
-            deadbeef->mutex_unlock (mutex);
             return -1;
         }
     }
-    deadbeef->mutex_unlock (mutex);
 
     return 0;
 }
@@ -520,20 +493,17 @@ ca_pause (void) {
         }
     }
 
-    deadbeef->mutex_lock (mutex);
+    ddb_playback_state_t curr_state = ca_state();
 
-    if (state != DDB_PLAYBACK_STATE_PAUSED) {
-        state = DDB_PLAYBACK_STATE_PAUSED;
+    if (curr_state != DDB_PLAYBACK_STATE_PAUSED) {
+        ca_set_state(DDB_PLAYBACK_STATE_PAUSED);
         err = AudioDeviceStop (device_id, ca_buffer_callback);
         if (err != noErr) {
             trace ("AudioDeviceStop: %x\n", err);
-            state = DDB_PLAYBACK_STATE_STOPPED;
-            deadbeef->mutex_unlock (mutex);
+            ca_set_state(DDB_PLAYBACK_STATE_STOPPED);
             return -1;
         }
     }
-
-    deadbeef->mutex_unlock (mutex);
     return 0;
 }
 
@@ -578,7 +548,11 @@ ca_buffer_callback(AudioDeviceID inDevice, const AudioTimeStamp * inNow, const A
     char *buffer = outOutputData->mBuffers[0].mData;
     sz = outOutputData->mBuffers[0].mDataByteSize;
 
-    if (state == DDB_PLAYBACK_STATE_PLAYING && deadbeef->streamer_ok_to_read (-1)) {
+    deadbeef->mutex_lock (mutex);
+    int st = state;
+    deadbeef->mutex_unlock (mutex);
+
+    if (st == DDB_PLAYBACK_STATE_PLAYING && deadbeef->streamer_ok_to_read (-1)) {
         int br = deadbeef->streamer_read (buffer, sz);
         if (br < 0) {
             br = 0;
@@ -601,7 +575,17 @@ ca_unpause (void) {
 
 static ddb_playback_state_t
 ca_state (void) {
-    return state;
+    deadbeef->mutex_lock (mutex);
+    int ret = state;
+    deadbeef->mutex_unlock (mutex);
+    return ret;
+}
+
+static void
+ca_set_state(ddb_playback_state_t st) {
+    deadbeef->mutex_lock (mutex);
+    state = st;
+    deadbeef->mutex_unlock (mutex);
 }
 
 static void ca_enum_soundcards (void (*callback)(const char *name, const char *desc, void*), void *userdata) {
@@ -703,7 +687,7 @@ static DB_output_t plugin = {
     .plugin.descr = "CoreAudio output plugin",
     .plugin.copyright =
         "DeaDBeeF CoreAudio output plugin\n"
-        "Copyright (C) 2009-2017 Alexey Yakovenko and other contributors\n"
+        "Copyright (C) 2009-2017 Oleksiy Yakovenko and other contributors\n"
         "Copyright (C) 2016 Christopher Snowhill\n"
         "\n"
         "This software is provided 'as-is', without any express or implied\n"
