@@ -1,6 +1,6 @@
 /*
     DeaDBeeF -- the music player
-    Copyright (C) 2009-2015 Alexey Yakovenko and other contributors
+    Copyright (C) 2009-2015 Oleksiy Yakovenko and other contributors
 
     This software is provided 'as-is', without any express or implied
     warranty.  In no event will the authors be held liable for any damages
@@ -84,35 +84,35 @@ get_pango_alignment (int align)
 }
 
 void
-draw_begin (drawctx_t *ctx, cairo_t *cr) {
+draw_begin (drawctx_t * const ctx, cairo_t *cr) {
     ctx->drawable = cr;
 }
 
 void
-draw_end (drawctx_t *ctx) {
+draw_end (drawctx_t * const ctx) {
     ctx->drawable = NULL;
 }
 
 void
-draw_set_fg_color (drawctx_t *ctx, float *rgb) {
+draw_set_fg_color (drawctx_t * const ctx, float *rgb) {
     cairo_set_source_rgb (ctx->drawable, rgb[0], rgb[1], rgb[2]);
 }
 
 void
-draw_line (drawctx_t *ctx, float x1, float y1, float x2, float y2) {
+draw_line (drawctx_t * const ctx, float x1, float y1, float x2, float y2) {
     cairo_move_to (ctx->drawable, x1, y1);
     cairo_line_to (ctx->drawable, x2, y2);
     cairo_stroke (ctx->drawable);
 }
 
 void
-draw_rect (drawctx_t *ctx, float x, float y, float w, float h, int fill) {
+draw_rect (drawctx_t * const ctx, float x, float y, float w, float h, int fill) {
     cairo_rectangle (ctx->drawable, x, y, w, h);
     fill ? cairo_fill (ctx->drawable) : cairo_stroke (ctx->drawable);
 }
 
 void
-draw_free (drawctx_t *ctx) {
+draw_free (drawctx_t * const ctx) {
     draw_end (ctx);
     if (ctx->pangoctx) {
         g_object_unref (ctx->pangoctx);
@@ -129,7 +129,7 @@ draw_free (drawctx_t *ctx) {
 }
 
 void
-draw_init_font (drawctx_t *ctx, int type, int reset) {
+draw_init_font (drawctx_t * const ctx, int type, int reset) {
     if (reset || !ctx->pango_ready) {
         if (ctx->pangoctx) {
             g_object_unref (ctx->pangoctx);
@@ -165,7 +165,7 @@ draw_init_font (drawctx_t *ctx, int type, int reset) {
 }
 
 void
-draw_init_font_style (drawctx_t *ctx, int bold, int italic, int type) {
+draw_init_font_style (drawctx_t * const ctx, int bold, int italic, int type) {
     PangoFontDescription *desc_default = ctx->font_style->font_desc;
     if (desc_default != NULL) {
         pango_layout_set_font_description (ctx->pangolayout, desc_default);
@@ -182,13 +182,13 @@ draw_init_font_style (drawctx_t *ctx, int bold, int italic, int type) {
 }
 
 void
-draw_init_font_normal (drawctx_t *ctx) {
+draw_init_font_normal (drawctx_t * const ctx) {
     pango_font_description_set_weight (ctx->font_style->font_desc, ctx->font_weight);
     pango_layout_set_font_description (ctx->pangolayout, ctx->font_style->font_desc);
 }
 
 float
-draw_get_font_size (drawctx_t *ctx) {
+draw_get_font_size (drawctx_t * const ctx) {
     draw_init_font (ctx, 0, 0);
     GdkScreen *screen = gdk_screen_get_default ();
     float dpi = gdk_screen_get_resolution (screen);
@@ -197,7 +197,7 @@ draw_get_font_size (drawctx_t *ctx) {
 }
 
 void
-draw_text (drawctx_t *ctx, float x, float y, int width, int align, const char *text) {
+draw_text (drawctx_t * const ctx, float x, float y, int width, int align, const char *text) {
     draw_init_font (ctx, 0, 0);
     pango_layout_set_width (ctx->pangolayout, width*PANGO_SCALE);
     pango_layout_set_alignment (ctx->pangolayout, get_pango_alignment (align));
@@ -207,7 +207,7 @@ draw_text (drawctx_t *ctx, float x, float y, int width, int align, const char *t
 }
 
 void
-draw_text_custom (drawctx_t *ctx, float x, float y, int width, int align, int type, int bold, int italic, const char *text) {
+draw_text_custom (drawctx_t * const ctx, float x, float y, int width, int align, int type, int bold, int italic, const char *text) {
     draw_init_font (ctx, type, 0);
     if (bold || italic) {
         draw_init_font_style (ctx, bold, italic, type);
@@ -220,7 +220,7 @@ draw_text_custom (drawctx_t *ctx, float x, float y, int width, int align, int ty
 }
 
 void
-draw_text_with_colors (drawctx_t *ctx, float x, float y, int width, int align, const char *text) {
+draw_text_with_colors (drawctx_t * const ctx, float x, float y, int width, int align, const char *text) {
     draw_init_font (ctx, 0, 0);
     pango_layout_set_width (ctx->pangolayout, width*PANGO_SCALE);
     pango_layout_set_alignment (ctx->pangolayout, get_pango_alignment (align));
@@ -231,7 +231,7 @@ draw_text_with_colors (drawctx_t *ctx, float x, float y, int width, int align, c
 }
 
 void
-draw_get_layout_extents (drawctx_t *ctx, int *w, int *h) {
+draw_get_layout_extents (drawctx_t * const ctx, int *w, int *h) {
     PangoRectangle log;
     pango_layout_get_pixel_extents (ctx->pangolayout, NULL, &log);
     if (w) {
@@ -243,7 +243,7 @@ draw_get_layout_extents (drawctx_t *ctx, int *w, int *h) {
 }
 
 void
-draw_get_text_extents (drawctx_t *ctx, const char *text, int len, int *w, int *h) {
+draw_get_text_extents (drawctx_t * const ctx, const char *text, int len, int *w, int *h) {
     draw_init_font (ctx, 0, 0);
     pango_layout_set_width (ctx->pangolayout, -1);
     pango_layout_set_alignment (ctx->pangolayout, PANGO_ALIGN_LEFT);
@@ -252,17 +252,17 @@ draw_get_text_extents (drawctx_t *ctx, const char *text, int len, int *w, int *h
 }
 
 int
-draw_is_ellipsized (drawctx_t *ctx) {
+draw_is_ellipsized (drawctx_t * const ctx) {
     return pango_layout_is_ellipsized (ctx->pangolayout);
 }
 
 const char *
-draw_get_text (drawctx_t *ctx) {
+draw_get_text (drawctx_t * const ctx) {
     return pango_layout_get_text (ctx->pangolayout);
 }
 
 int
-draw_get_listview_rowheight (drawctx_t *ctx) {
+draw_get_listview_rowheight (drawctx_t * const ctx) {
     PangoFontDescription *font_desc = pango_font_description_copy (pango_layout_get_font_description (ctx->pangolayout));
     PangoFontMetrics *metrics = pango_context_get_metrics (ctx->pangoctx,
             font_desc,
@@ -275,7 +275,7 @@ draw_get_listview_rowheight (drawctx_t *ctx) {
 }
 
 void
-drawctx_init (drawctx_t *ctx) {
+drawctx_init (drawctx_t * const ctx) {
     memset (ctx, 0, sizeof (drawctx_t));
     ctx->font_weight = PANGO_WEIGHT_NORMAL;
 }
@@ -301,9 +301,14 @@ static GdkColor gtkui_listview_group_text_color;
 static GdkColor gtkui_listview_column_text_color;
 static GdkColor gtkui_listview_cursor_color;
 
+static GdkColor gtkui_visualization_base_color;
+static GdkColor gtkui_visualization_background_color;
+
 static int override_listview_colors = 0;
 static int override_bar_colors = 0;
 static int override_tabstrip_colors = 0;
+static int use_custom_visualization_color = 0;
+static int use_custom_visualization_background_color = 0;
 
 int
 gtkui_listview_override_conf (const char *conf_str) {
@@ -370,12 +375,12 @@ gtkui_override_tabstrip_colors (void) {
     return override_tabstrip_colors;
 }
 
+#if 0
 static void
 color_dump (const char *name, GdkColor *c) {
     printf ("%s: %x %x %x\n", name, c->red>>8, c->green>>8, c->blue>>8);
 }
 
-static guint16
 color_lerp_component (guint16 from, guint16 to, float factor) {
     int32_t result = (int32_t)from + (int32_t)(((int32_t)to - (int32_t)from) * factor);
     if (result < 0) {
@@ -395,6 +400,15 @@ color_lerp (GdkColor from, GdkColor to, float factor) {
     result.blue = color_lerp_component(from.blue, to.blue, factor);
     return result;
 }
+#endif
+
+static void
+_init_color_for_name(GdkColor *color, const char *name, const GdkColor *def) {
+    char color_text[100];
+    snprintf (color_text, sizeof (color_text), "%hd %hd %hd", def->red, def->green, def->blue);
+    const char *clr = deadbeef->conf_get_str_fast (name, color_text);
+    sscanf (clr, "%hd %hd %hd", &color->red, &color->green, &color->blue);
+}
 
 void
 gtkui_init_theme_colors (void) {
@@ -406,34 +420,55 @@ gtkui_init_theme_colors (void) {
     override_listview_colors= deadbeef->conf_get_int ("gtkui.override_listview_colors", 0);
     override_bar_colors = deadbeef->conf_get_int ("gtkui.override_bar_colors", 0);
     override_tabstrip_colors = deadbeef->conf_get_int ("gtkui.override_tabstrip_colors", 0);
+    use_custom_visualization_color = deadbeef->conf_get_int ("gtkui.vis.use_custom_base_color", 0);
+    use_custom_visualization_background_color = deadbeef->conf_get_int ("gtkui.vis.use_custom_background_color", 0);
 
     extern GtkWidget *mainwin;
     GtkStyle *style = gtk_widget_get_style (mainwin);
     GtkStyle *entry_style = gtk_widget_get_style (theme_entry);
-    char color_text[100];
-    const char *clr;
     char *font_name = pango_font_description_to_string (style->font_desc);
 
+    // HACK: if gtk says selected color is the same as background -- set it
+    // to a shade of blue
+    int use_hardcoded_accent_color = memcmp (&style->bg[GTK_STATE_NORMAL], &gtkui_bar_foreground_color, sizeof (gtkui_bar_foreground_color));
+
+    GdkColor hardcoded_accent_color = {
+        .red = 0x2b84,
+        .green = 0x7fff,
+        .blue = 0xbae0,
+    };
+
+    if (use_hardcoded_accent_color) {
+        memcpy (&gtkui_visualization_base_color, &hardcoded_accent_color, sizeof (GdkColor));
+    }
+    else {
+        memcpy (&gtkui_visualization_base_color, &style->base[GTK_STATE_SELECTED], sizeof (GdkColor));
+    }
+
+    if (use_custom_visualization_color) {
+        _init_color_for_name(&gtkui_visualization_base_color, "gtkui.vis.custom_base_color", &gtkui_visualization_base_color);
+    }
+
+    if (use_custom_visualization_background_color) {
+        _init_color_for_name(&gtkui_visualization_background_color, "gtkui.vis.custom_background_color", &gtkui_visualization_background_color);
+    }
+    else {
+        memcpy (&gtkui_visualization_background_color, &style->black, sizeof (GdkColor));
+    }
+
     if (!override_bar_colors) {
-        memcpy (&gtkui_bar_foreground_color, &style->base[GTK_STATE_SELECTED], sizeof (GdkColor));
         memcpy (&gtkui_bar_background_color, &style->text[GTK_STATE_NORMAL], sizeof (GdkColor));
 
-        // HACK: if gtk says selected color is the same as background -- set it
-        // to a shade of blue
-        if (!memcmp (&style->bg[GTK_STATE_NORMAL], &gtkui_bar_foreground_color, sizeof (gtkui_bar_foreground_color))) {
-            gtkui_bar_foreground_color.red = 0x2b84;
-            gtkui_bar_foreground_color.green = 0x7fff;
-            gtkui_bar_foreground_color.blue = 0xbae0;
+        if (use_hardcoded_accent_color) {
+            memcpy (&gtkui_bar_foreground_color, &hardcoded_accent_color, sizeof (GdkColor));
+        }
+        else {
+            memcpy (&gtkui_bar_foreground_color, &style->base[GTK_STATE_SELECTED], sizeof (GdkColor));
         }
     }
     else {
-        snprintf (color_text, sizeof (color_text), "%hd %hd %hd", entry_style->base[GTK_STATE_SELECTED].red, entry_style->base[GTK_STATE_SELECTED].green, entry_style->base[GTK_STATE_SELECTED].blue);
-        clr = deadbeef->conf_get_str_fast ("gtkui.color.bar_foreground", color_text);
-        sscanf (clr, "%hd %hd %hd", &gtkui_bar_foreground_color.red, &gtkui_bar_foreground_color.green, &gtkui_bar_foreground_color.blue);
-
-        snprintf (color_text, sizeof (color_text), "%hd %hd %hd", entry_style->fg[GTK_STATE_NORMAL].red, entry_style->fg[GTK_STATE_NORMAL].green, entry_style->fg[GTK_STATE_NORMAL].blue);
-        clr = deadbeef->conf_get_str_fast ("gtkui.color.bar_background", color_text);
-        sscanf (clr, "%hd %hd %hd", &gtkui_bar_background_color.red, &gtkui_bar_background_color.green, &gtkui_bar_background_color.blue);
+        _init_color_for_name(&gtkui_bar_foreground_color, "gtkui.color.bar_foreground", &entry_style->base[GTK_STATE_SELECTED]);
+        _init_color_for_name(&gtkui_bar_background_color, "gtkui.color.bar_background", &entry_style->fg[GTK_STATE_NORMAL]);
     }
 
     if (!override_tabstrip_colors) {
@@ -447,33 +482,13 @@ gtkui_init_theme_colors (void) {
         strncpy (gtkui_tabstrip_text_font, font_name, sizeof (gtkui_tabstrip_text_font));
     }
     else {
-        snprintf (color_text, sizeof (color_text), "%hd %hd %hd", style->dark[GTK_STATE_NORMAL].red, style->dark[GTK_STATE_NORMAL].green, style->dark[GTK_STATE_NORMAL].blue);
-        clr = deadbeef->conf_get_str_fast ("gtkui.color.tabstrip_dark", color_text);
-        sscanf (clr, "%hd %hd %hd", &gtkui_tabstrip_dark_color.red, &gtkui_tabstrip_dark_color.green, &gtkui_tabstrip_dark_color.blue);
-
-        snprintf (color_text, sizeof (color_text), "%hd %hd %hd", style->mid[GTK_STATE_NORMAL].red, style->mid[GTK_STATE_NORMAL].green, style->mid[GTK_STATE_NORMAL].blue);
-        clr = deadbeef->conf_get_str_fast ("gtkui.color.tabstrip_mid", color_text);
-        sscanf (clr, "%hd %hd %hd", &gtkui_tabstrip_mid_color.red, &gtkui_tabstrip_mid_color.green, &gtkui_tabstrip_mid_color.blue);
-
-        snprintf (color_text, sizeof (color_text), "%hd %hd %hd", style->light[GTK_STATE_NORMAL].red, style->light[GTK_STATE_NORMAL].green, style->light[GTK_STATE_NORMAL].blue);
-        clr = deadbeef->conf_get_str_fast ("gtkui.color.tabstrip_light", color_text);
-        sscanf (clr, "%hd %hd %hd", &gtkui_tabstrip_light_color.red, &gtkui_tabstrip_light_color.green, &gtkui_tabstrip_light_color.blue);
-
-        snprintf (color_text, sizeof (color_text), "%hd %hd %hd", style->bg[GTK_STATE_NORMAL].red, style->bg[GTK_STATE_NORMAL].green, style->bg[GTK_STATE_NORMAL].blue);
-        clr = deadbeef->conf_get_str_fast ("gtkui.color.tabstrip_base", color_text);
-        sscanf (clr, "%hd %hd %hd", &gtkui_tabstrip_base_color.red, &gtkui_tabstrip_base_color.green, &gtkui_tabstrip_base_color.blue);
-
-        snprintf (color_text, sizeof (color_text), "%hd %hd %hd", style->text[GTK_STATE_NORMAL].red, style->text[GTK_STATE_NORMAL].green, style->text[GTK_STATE_NORMAL].blue);
-        clr = deadbeef->conf_get_str_fast ("gtkui.color.tabstrip_text", color_text);
-        sscanf (clr, "%hd %hd %hd", &gtkui_tabstrip_text_color.red, &gtkui_tabstrip_text_color.green, &gtkui_tabstrip_text_color.blue);
-
-        snprintf (color_text, sizeof (color_text), "%hd %hd %hd", style->text[GTK_STATE_NORMAL].red, style->text[GTK_STATE_NORMAL].green, style->text[GTK_STATE_NORMAL].blue);
-        clr = deadbeef->conf_get_str_fast ("gtkui.color.tabstrip_playing_text", color_text);
-        sscanf (clr, "%hd %hd %hd", &gtkui_tabstrip_playing_text_color.red, &gtkui_tabstrip_playing_text_color.green, &gtkui_tabstrip_playing_text_color.blue);
-
-        snprintf (color_text, sizeof (color_text), "%hd %hd %hd", style->text[GTK_STATE_NORMAL].red, style->text[GTK_STATE_NORMAL].green, style->text[GTK_STATE_NORMAL].blue);
-        clr = deadbeef->conf_get_str_fast ("gtkui.color.tabstrip_selected_text", color_text);
-        sscanf (clr, "%hd %hd %hd", &gtkui_tabstrip_selected_text_color.red, &gtkui_tabstrip_selected_text_color.green, &gtkui_tabstrip_selected_text_color.blue);
+        _init_color_for_name(&gtkui_tabstrip_dark_color, "gtkui.color.tabstrip_dark", &style->dark[GTK_STATE_NORMAL]);
+        _init_color_for_name(&gtkui_tabstrip_mid_color, "gtkui.color.tabstrip_mid", &style->mid[GTK_STATE_NORMAL]);
+        _init_color_for_name(&gtkui_tabstrip_light_color, "gtkui.color.tabstrip_light", &style->light[GTK_STATE_NORMAL]);
+        _init_color_for_name(&gtkui_tabstrip_base_color, "gtkui.color.tabstrip_base", &style->bg[GTK_STATE_NORMAL]);
+        _init_color_for_name(&gtkui_tabstrip_text_color, "gtkui.color.tabstrip_text", &style->text[GTK_STATE_NORMAL]);
+        _init_color_for_name(&gtkui_tabstrip_playing_text_color, "gtkui.color.tabstrip_playing_text", &style->text[GTK_STATE_NORMAL]);
+        _init_color_for_name(&gtkui_tabstrip_selected_text_color, "gtkui.color.tabstrip_selected_text", &style->text[GTK_STATE_NORMAL]);
 
         strncpy (gtkui_tabstrip_text_font, deadbeef->conf_get_str_fast ("gtkui.font.tabstrip_text", font_name), sizeof (gtkui_tabstrip_text_font));
     }
@@ -493,41 +508,15 @@ gtkui_init_theme_colors (void) {
         strncpy (gtkui_listview_column_text_font, font_name, sizeof (gtkui_listview_column_text_font));
     }
     else {
-        snprintf (color_text, sizeof (color_text), "%hd %hd %hd", style->light[GTK_STATE_NORMAL].red, style->light[GTK_STATE_NORMAL].green, style->light[GTK_STATE_NORMAL].blue);
-        clr = deadbeef->conf_get_str_fast ("gtkui.color.listview_even_row", color_text);
-        sscanf (clr, "%hd %hd %hd", &gtkui_listview_even_row_color.red, &gtkui_listview_even_row_color.green, &gtkui_listview_even_row_color.blue);
-
-        snprintf (color_text, sizeof (color_text), "%hd %hd %hd", style->mid[GTK_STATE_NORMAL].red, style->mid[GTK_STATE_NORMAL].green, style->mid[GTK_STATE_NORMAL].blue);
-        clr = deadbeef->conf_get_str_fast ("gtkui.color.listview_odd_row", color_text);
-        sscanf (clr, "%hd %hd %hd", &gtkui_listview_odd_row_color.red, &gtkui_listview_odd_row_color.green, &gtkui_listview_odd_row_color.blue);
-
-        snprintf (color_text, sizeof (color_text), "%hd %hd %hd", style->bg[GTK_STATE_SELECTED].red, style->bg[GTK_STATE_SELECTED].green, style->bg[GTK_STATE_SELECTED].blue);
-        clr = deadbeef->conf_get_str_fast ("gtkui.color.listview_selection", color_text);
-        sscanf (clr, "%hd %hd %hd", &gtkui_listview_selection_color.red, &gtkui_listview_selection_color.green, &gtkui_listview_selection_color.blue);
-
-        snprintf (color_text, sizeof (color_text), "%hd %hd %hd", style->fg[GTK_STATE_NORMAL].red, style->fg[GTK_STATE_NORMAL].green, style->fg[GTK_STATE_NORMAL].blue);
-        clr = deadbeef->conf_get_str_fast ("gtkui.color.listview_text", color_text);
-        sscanf (clr, "%hd %hd %hd", &gtkui_listview_text_color.red, &gtkui_listview_text_color.green, &gtkui_listview_text_color.blue);
-
-        snprintf (color_text, sizeof (color_text), "%hd %hd %hd", style->fg[GTK_STATE_SELECTED].red, style->fg[GTK_STATE_SELECTED].green, style->fg[GTK_STATE_SELECTED].blue);
-        clr = deadbeef->conf_get_str_fast ("gtkui.color.listview_selected_text", color_text);
-        sscanf (clr, "%hd %hd %hd", &gtkui_listview_selected_text_color.red, &gtkui_listview_selected_text_color.green, &gtkui_listview_selected_text_color.blue);
-
-        snprintf (color_text, sizeof (color_text), "%hd %hd %hd", style->fg[GTK_STATE_NORMAL].red, style->fg[GTK_STATE_NORMAL].green, style->fg[GTK_STATE_NORMAL].blue);
-        clr = deadbeef->conf_get_str_fast ("gtkui.color.listview_playing_text", color_text);
-        sscanf (clr, "%hd %hd %hd", &gtkui_listview_playing_text_color.red, &gtkui_listview_playing_text_color.green, &gtkui_listview_playing_text_color.blue);
-
-        snprintf (color_text, sizeof (color_text), "%hd %hd %hd", style->fg[GTK_STATE_NORMAL].red, style->fg[GTK_STATE_NORMAL].green, style->fg[GTK_STATE_NORMAL].blue);
-        clr = deadbeef->conf_get_str_fast ("gtkui.color.listview_group_text", color_text);
-        sscanf (clr, "%hd %hd %hd", &gtkui_listview_group_text_color.red, &gtkui_listview_group_text_color.green, &gtkui_listview_group_text_color.blue);
-
-        snprintf (color_text, sizeof (color_text), "%hd %hd %hd", style->fg[GTK_STATE_NORMAL].red, style->fg[GTK_STATE_NORMAL].green, style->fg[GTK_STATE_NORMAL].blue);
-        clr = deadbeef->conf_get_str_fast ("gtkui.color.listview_column_text", color_text);
-        sscanf (clr, "%hd %hd %hd", &gtkui_listview_column_text_color.red, &gtkui_listview_column_text_color.green, &gtkui_listview_column_text_color.blue);
-
-        snprintf (color_text, sizeof (color_text), "%hd %hd %hd", style->fg[GTK_STATE_SELECTED].red, style->fg[GTK_STATE_SELECTED].green, style->fg[GTK_STATE_SELECTED].blue);
-        clr = deadbeef->conf_get_str_fast ("gtkui.color.listview_cursor", color_text);
-        sscanf (clr, "%hd %hd %hd", &gtkui_listview_cursor_color.red, &gtkui_listview_cursor_color.green, &gtkui_listview_cursor_color.blue);
+        _init_color_for_name(&gtkui_listview_even_row_color, "gtkui.color.listview_even_row", &style->light[GTK_STATE_NORMAL]);
+        _init_color_for_name(&gtkui_listview_odd_row_color, "gtkui.color.listview_odd_row", &style->mid[GTK_STATE_NORMAL]);
+        _init_color_for_name(&gtkui_listview_selection_color, "gtkui.color.listview_selection", &style->bg[GTK_STATE_SELECTED]);
+        _init_color_for_name(&gtkui_listview_text_color, "gtkui.color.listview_text", &style->fg[GTK_STATE_NORMAL]);
+        _init_color_for_name(&gtkui_listview_selected_text_color, "gtkui.color.listview_selected_text", &style->fg[GTK_STATE_SELECTED]);
+        _init_color_for_name(&gtkui_listview_playing_text_color, "gtkui.color.listview_playing_text", &style->fg[GTK_STATE_NORMAL]);
+        _init_color_for_name(&gtkui_listview_group_text_color, "gtkui.color.listview_group_text", &style->fg[GTK_STATE_NORMAL]);
+        _init_color_for_name(&gtkui_listview_column_text_color, "gtkui.color.listview_column_text", &style->fg[GTK_STATE_NORMAL]);
+        _init_color_for_name(&gtkui_listview_cursor_color, "gtkui.color.listview_cursor", &style->fg[GTK_STATE_SELECTED]);
 
         strncpy (gtkui_listview_text_font, deadbeef->conf_get_str_fast ("gtkui.font.listview_text", font_name), sizeof (gtkui_listview_text_font));
         strncpy (gtkui_listview_group_text_font, deadbeef->conf_get_str_fast ("gtkui.font.listview_group_text", font_name), sizeof (gtkui_listview_group_text_font));
@@ -540,6 +529,16 @@ gtkui_init_theme_colors (void) {
     deadbeef->conf_unlock ();
 }
 
+void
+gtkui_get_vis_custom_base_color (GdkColor *clr) {
+    memcpy (clr, &gtkui_visualization_base_color, sizeof (GdkColor));
+}
+
+void
+gtkui_get_vis_custom_background_color (GdkColor *clr) {
+    memcpy (clr, &gtkui_visualization_background_color, sizeof (GdkColor));
+}
+
 void
 gtkui_get_bar_foreground_color (GdkColor *clr) {
     memcpy (clr, &gtkui_bar_foreground_color, sizeof (GdkColor));
