@@ -30,7 +30,7 @@ if _OPTIONS["standard"] ~= nil then
   plugins_to_disable = {"plugin-converter", "plugin-converter_gtk2",
                         "plugin-converter_gtk3","plugin-ffmpeg","plugin-waveout",
                         "plugin-wildmidi", "plugin-soundtouch", "plugin-sid", "plugin-gme",
-                        "plugin-mms", "plugin-cdda", "plugin-sc68", "plugin-vtx", "plugin-medialib"}
+                        "plugin-mms", "plugin-cdda", "plugin-sc68", "plugin-vtx"}
   for i,v in ipairs(plugins_to_disable) do
     if _OPTIONS[v] == nil then
       _OPTIONS[v] = "disabled"
@@ -77,6 +77,7 @@ filter "configurations:debug or release"
 
 
 filter "platforms:Windows"
+  WINDOWS_SYSTEM_PREFIX = (os.getenv("MSYSTEM_PREFIX") or '')
   buildoptions {
     "-include shared/windows/mingw32_layer.h",
     "-fno-builtin"
@@ -86,7 +87,7 @@ filter "platforms:Windows"
   }
   includedirs {
     "shared/windows/include",
-    "/mingw64/include/opus",
+    WINDOWS_SYSTEM_PREFIX .. "/include/opus",
     "xdispatch_ddb/include"
   }
   libdirs {
@@ -113,7 +114,7 @@ filter 'files:**.rc'
 filter 'files:**.asm'
   buildmessage 'YASM Assembling : %{file.relpath}'
   buildcommands {'mkdir -p obj/%{cfg.buildcfg}/ffap/'}
-  buildcommands {'yasm -f elf -D ARCH_X86_64 -m amd64 -DPIC -DPREFIX -o "obj/%{cfg.buildcfg}/ffap/%{file.basename}.o" "%{file.relpath}"'}
+  buildcommands {'yasm -f win64 -D ARCH_X86_64 -m amd64 -DPIC -DPREFIX -o "obj/%{cfg.buildcfg}/ffap/%{file.basename}.o" "%{file.relpath}"'}
   buildoutputs {"obj/%{cfg.buildcfg}/ffap/%{file.basename}.o"}
 
 -- Libraries
@@ -204,7 +205,8 @@ project "deadbeef"
     "DOCDIR=\"donotuse\"",
     "LOCALEDIR=\"donotuse\""
   }
-  links { "m", "pthread", "dl"}
+  buildoptions {"-fblocks"}
+  links { "m", "pthread", "dl","dispatch", "BlocksRuntime"}
   filter "platforms:Windows"
     files {
       "icons/deadbeef-icon.rc",
@@ -238,11 +240,13 @@ end
 if _OPTIONS["plugin-aac"] == "auto" or _OPTIONS["plugin-aac"] == nil then
   -- hard-coded :(
   -- todo: linuxify
-  if os.outputof("ls /mingw64/include/neaacdec.h") == nil  then
-    print ("\27[93m" .. "neaacdec.h not found in \"/mingw64/include/\", run premake5 with \"--plugin-aac=enabled\" to force enable aac plugin" ..  "\27[39m")
+  if os.outputof("ls " .. WINDOWS_SYSTEM_PREFIX .. "/include/neaacdec.h") == nil  then
+    print ("\27[93m" .. "neaacdec.h not found in \"" .. WINDOWS_SYSTEM_PREFIX .. "/include/\", run premake5 with \"--plugin-aac=enabled\" to force enable aac plugin" ..  "\27[39m")
     _OPTIONS["plugin-aac"] = "disabled"
+    _OPTIONS["plugin-alac"] = "disabled"
   else
     _OPTIONS["plugin-aac"] = "enabled"
+    _OPTIONS["plugin-alac"] = "enabled"
   end
 end
 
@@ -322,8 +326,6 @@ project "dca_plugin"
     "plugins/dca/bitstream.c",
     "plugins/dca/downmix.c"
   }
-  prebuildcommands {"touch plugins/dca/config.h"}
-  postbuildcommands {"rm plugins/dca/config.h"}
 end
 
 if option ("plugin-dumb") then
@@ -519,7 +521,7 @@ project "gme_plugin"
     "plugins/gme/game-music-emu-0.6pre/gme/",
     "plugins/gme/game-music-emu-0.6pre"
   }
-  defines {"GME_VERSION_055"}
+  defines {"GME_VERSION_055","HAVE_STDINT_H"}
   links {"stdc++", "z"}
   filter 'files:**.cpp'
     buildoptions {"-include cstdint"}
@@ -570,7 +572,7 @@ end
 
 if option ("plugin-sc68") then
 project "sc68_plugin"
-  targetname "sc68"
+  targetname "in_sc68"
   files {
     "plugins/sc68/in_sc68.c",
     "plugins/sc68/file68/src/*.c",
@@ -805,9 +807,15 @@ if option ("plugin-gtk2", "gtk+-2.0 jansson") then
 project "ddb_gui_GTK2"
   files {
     "plugins/gtkui/*.c",
+    "plugins/gtkui/medialib/*.c",
+    "plugins/gtkui/prefwin/*.c",
+    "plugins/gtkui/covermanager/*.c",
+    "plugins/gtkui/playlist/*.c",
     "shared/eqpreset.c",
     "shared/pluginsettings.c",
     "shared/trkproperties_shared.c",
+    "analyzer/analyzer.c",
+    "scope/scope.c",
     "plugins/libparser/parser.c",
     "utf8.c"
   }
@@ -819,8 +827,9 @@ project "ddb_gui_GTK2"
     "plugins/gtkui",
     "plugins/libparser"
   }
+  buildoptions {"-fblocks"}
   pkgconfig ("gtk+-2.0 jansson")
-  links {"libdeletefromdisk", "libtftintutil"}
+  links {"libdeletefromdisk", "libtftintutil", "dispatch", "BlocksRuntime"}
   defines ("GLIB_DISABLE_DEPRECATION_WARNINGS")
 end
 
@@ -828,9 +837,15 @@ if option ("plugin-gtk3", "gtk+-3.0 jansson") then
 project "ddb_gui_GTK3"
   files {
     "plugins/gtkui/*.c",
+    "plugins/gtkui/medialib/*.c",
+    "plugins/gtkui/prefwin/*.c",
+    "plugins/gtkui/covermanager/*.c",
+    "plugins/gtkui/playlist/*.c",
     "shared/eqpreset.c",
     "shared/pluginsettings.c",
     "shared/trkproperties_shared.c",
+    "analyzer/analyzer.c",
+    "scope/scope.c",
     "plugins/libparser/parser.c",
     "utf8.c"
   }
@@ -843,8 +858,9 @@ project "ddb_gui_GTK3"
     "glib-compile-resources --sourcedir=plugins/gtkui --target=plugins/gtkui/gtkui-gresources.c --generate-source plugins/gtkui/gtkui.gresources.xml"
   }
 
+  buildoptions {"-fblocks"}
   pkgconfig("gtk+-3.0 jansson")
-  links {"libdeletefromdisk", "libtftintutil"}
+  links {"libdeletefromdisk", "libtftintutil", "dispatch", "BlocksRuntime"}
   defines ("GLIB_DISABLE_DEPRECATION_WARNINGS")
 end
 
@@ -854,6 +870,8 @@ project "rg_scanner"
     "plugins/rg_scanner/*.c",
     "plugins/rg_scanner/ebur128/*.c"
   }
+  buildoptions {"-fblocks"}
+  links {"dispatch", "BlocksRuntime"}
 end
 
 if option ("plugin-converter") then
@@ -1091,16 +1109,20 @@ project "musepack_plugin"
   links {"m"}
 end
 
-if option ("plugin-artwork", "libjpeg libpng zlib flac ogg") then
+if option ("plugin-artwork", "flac ogg vorbisfile") then
 project "artwork_plugin"
   targetname "artwork"
   files {
-    "plugins/artwork-legacy/*.c",
+    "plugins/artwork/*.c",
     "shared/mp4tagutil.c"
   }
-  includedirs {"../libmp4ff"}
+  includedirs {"../libmp4ff", "./shared"}
+  buildoptions {"-fblocks"}
   defines {"USE_OGG=1", "USE_VFS_CURL", "USE_METAFLAC", "USE_MP4FF", "USE_TAGGING=1"}
-  links {"jpeg", "png", "z", "FLAC", "ogg", "mp4p"}
+  pkgconfig ("flac ogg vorbisfile")
+  links {"FLAC", "ogg", "vorbisfile", "mp4p", "dispatch", "BlocksRuntime"}
+else
+  options_dic["plugin-artwork"] = "no"
 end
 
 if option ("plugin-supereq") then
@@ -1156,12 +1178,14 @@ project "tta"
   }
 end
 
-if option ("plugin-medialib") then
-project "medialib"
+if option ("plugin-libretro") then
+project "ddb_dsp_libretro"
   files {
-    "plugins/medialib/medialib.c"
+    "external/ddb_dsp_libretro/libretro.cpp"
+  }
+  buildoptions {
+    "-msse3"
   }
-  pkgconfig ("jansson")
 end
 
 project "translations"
