@@ -4,7 +4,7 @@
 
   routines for converting between wave formats and channel configurations
 
-  Copyright (C) 2009-2013 Alexey Yakovenko
+  Copyright (C) 2009-2013 Oleksiy Yakovenko
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -22,7 +22,7 @@
      misrepresented as being the original software.
   3. This notice may not be removed or altered from any source distribution.
 
-  Alexey Yakovenko waker@users.sourceforge.net
+  Oleksiy Yakovenko waker@users.sourceforge.net
 */
 
 #include <assert.h>
@@ -363,6 +363,7 @@ pcm_write_samples_32_to_float (const ddb_waveformat_t * restrict inputfmt, const
 static inline void
 pcm_write_samples_float_to_8 (const ddb_waveformat_t * restrict inputfmt, const char * restrict input, const ddb_waveformat_t * restrict outputfmt, char * restrict output, int nsamples, int * restrict channelmap, int outputsamplesize) {
     fpu_control ctl = 0;
+    (void)ctl;
     fpu_setround (&ctl);
     for (int s = 0; s < nsamples; s++) {
         for (int c = 0; c < outputfmt->channels; c++) {
@@ -389,6 +390,7 @@ pcm_write_samples_float_to_8 (const ddb_waveformat_t * restrict inputfmt, const
 static inline void
 pcm_write_samples_float_to_16 (const ddb_waveformat_t * restrict inputfmt, const char * restrict input, const ddb_waveformat_t * restrict outputfmt, char * restrict output, int nsamples, int * restrict channelmap, int outputsamplesize) {
     fpu_control ctl = 0;
+    (void)ctl;
     fpu_setround (&ctl);
     for (int s = 0; s < nsamples; s++) {
         for (int c = 0; c < outputfmt->channels; c++) {
@@ -415,6 +417,7 @@ pcm_write_samples_float_to_16 (const ddb_waveformat_t * restrict inputfmt, const
 static inline void
 pcm_write_samples_float_to_24 (const ddb_waveformat_t * restrict inputfmt, const char * restrict input, const ddb_waveformat_t * restrict outputfmt, char * restrict output, int nsamples, int * restrict channelmap, int outputsamplesize) {
     fpu_control ctl = 0;
+    (void)ctl;
     fpu_setround (&ctl);
     for (int s = 0; s < nsamples; s++) {
         for (int c = 0; c < outputfmt->channels; c++) {
@@ -544,6 +547,7 @@ pcm_convert (const ddb_waveformat_t * restrict inputfmt, const char * restrict i
             channelmap[i] = -1;
         }
         uint32_t inputbitmask = 1;
+
         for (int i = 0; i < inputfmt->channels; i++) {
             // find next input channel
             while (inputbitmask < 0x80000000 && !(inputfmt->channelmask & inputbitmask)) {
@@ -565,12 +569,9 @@ pcm_convert (const ddb_waveformat_t * restrict inputfmt, const char * restrict i
                     continue;
                 }
                 outchannels |= outputbitmask;
-                channelmap[i] = o; // input channel i going to output channel o
+                channelmap[o] = i; // input channel i going to output channel o
                 //trace ("channelmap[%d]=%d\n", i, o);
             }
-            else {
-                channelmap[i] = -1;
-            }
             inputbitmask <<= 1;
         }
 
